@include('finance.js.finance-functions')
<div class="headers">
    <script>
        $('#finance').css('left', 0);
        $('.fa-university').closest('#finance').find('.fa-university').addClass('fa-spin');
    </script>
    <div class="control_headers" id="control_headers">
        <div class="dropdown">
            <a href="#" class="guestDetails_links inner"><b>Search</b> <i class="fa fa-search" aria-hidden="true"></i></a>
            <div class="dropdown-content" >
                <a href="javascript: void(0)" onclick="searchClient()"><i class="fa fa-group" aria-hidden="true"></i> &nbsp;&nbsp;Client </a>
                <a href="javascript: void(0)" onclick="searchPolicyFinance()"><i class="fa fa-list-alt" aria-hidden="true"></i> &nbsp;&nbsp;Debits & Credits</a>
                <a href="javascript: void(0)" onclick="searchReceipt()"><i class="fa fa-money" aria-hidden="true"></i> &nbsp;&nbsp;Receipt</a>
                <a href="javascript: void(0)" onclick="searchPremiumDirectPV()"><i class="fa fa-rub" aria-hidden="true"></i> &nbsp;&nbsp;Direct Premium PV</a>
                <a href="javascript: void(0)" onclick="searchCompanyLedger()"><i class="fa fa-indent" aria-hidden="true"></i> &nbsp;&nbsp;General Ledger</a>
            </div>
        </div>
        <div class="dropdown">
            <a href="#" class="guestDetails_links inner">Company</a>
            <div class="dropdown-content">
                <a href="{{url('receipts')}}">Receipts </a>
                <a href="{{url('payments')}}">Payments</a>
                <a href="{{url('#')}}">Cheque Printing</a>
                <a href="{{url('company-trial-balance')}}">Trial Balance </a>
                <a href="{{url('company-balance-sheet')}}">Balance Sheet</a>
                <a href="{{url('#')}}">Profit & Loss</a>
                {{--<a href="{{url('#')}}">Close Year</a>--}}
            </div>
        </div>
        <div class="dropdown">
            <a href="#" class="guestDetails_links inner">Requisitions</a>
            <div class="dropdown-content">
                <a href="{{url('requisition')}}">Requisitions </a>
                <a href="{{url('#')}}">Pending Authorization </a>
            </div>
        </div>
        {{-- <div class="dropdown">
             <a href="{{url('receipts')}}" class="guestDetails_links inner">Receipts</a>
         </div>--}}

        <div class="dropdown">
            <a href="#" class="guestDetails_links inner">Charts of Accounts</a>
            <div class="dropdown-content">
                {{--<a href="javascript: void(0)" onclick="createNewAccount()">Create a New Account</a>--}}
                <a href="{{url('charts-of-accounts')}}">Charts of Accounts </a>
                <a href="{{url('finance-main-ledgers')}}">Main Accounts</a>
                <a href="{{url('mapped-ledgers')}}">Mappable Ledgers</a>
                <a href="{{url('#')}}">General Ledger</a>
                <a href="{{url('#')}}">Bank Reconciliation</a>
                <a href="{{url('#')}}">Accounts Opening Bal</a>
            </div>
        </div>
        <div class="dropdown">
            <a href="#" class="guestDetails_links inner">Fixed Assets</a>
            <div class="dropdown-content">
                <a href="{{url('#')}}">Fixed Assets Listing </a>
                <a href="{{url('#')}}">Depreciation Manager</a>
                <a href="{{url('#')}}">Disposal Manager</a>
            </div>
        </div>
        <div class="dropdown">
            <a href="#" class="guestDetails_links inner">Petty Cash</a>
            <div class="dropdown-content">
                <a href="{{url('#')}}">Petty Cash Accounts </a>
                <a href="{{url('#')}}">Unauthorized Payments</a>
                <a href="{{url('#')}}">Payments Reports</a>
                <a href="{{url('#')}}">Cancelled Transactions</a>
            </div>
        </div>
        <div class="dropdown">
            <a href="#" class="guestDetails_links inner">Clients</a>
            <div class="dropdown-content">
                {{--<a href="javascript: void(0)" onclick="searchClientFinance()">Client's Project Details </a>--}}
                <a href="{{url('#')}}"><i class="fa fa-briefcase" aria-hidden="true"></i> &nbsp;&nbsp;Debtor's List</a>
                <a href="{{url('#')}}"><i class="fa fa-id-card-o"></i> &nbsp;&nbsp;Client Statement</a>
                <a href="{{url('#')}}"><i class="fa fa-money"></i> &nbsp;&nbsp;PD Cheques</a>
                <a href="{{url('#')}}"><i class="fa fa-university"></i> &nbsp;&nbsp;Opening Balances</a>
            </div>
        </div>
        <div class="dropdown">
            <a href="#" class="guestDetails_links inner">Employees</a>
            <div class="dropdown-content">
                <a href="{{url('#')}}"><i class="fa fa-money"></i> &nbsp;&nbsp;Salary Advances</a>
                <a href="{{url('manage-employee-payroll')}}"><i class="fa fa-paypal"></i> &nbsp;&nbsp;Payroll Manager</a>
            </div>
        </div>
        <div class="dropdown">
            <a href="#" class="guestDetails_links inner">Suppliers</a>
            <div class="dropdown-content">
                <a href="{{url('acc-vendors')}}"><i class="fa fa-users"></i> &nbsp;&nbsp;View Active Suppliers </a>
                <a href="{{url('acc-bills-manager')}}"><i class="fa fa-briefcase"></i> &nbsp;&nbsp;Bills Manager</a>
                <a href="{{url('setup-office-stationary')}}"><i class="fa fa-building"></i> &nbsp;&nbsp;Office Stationary</a>
                <a href="{{url('setup-kitchen-consumables')}}"><i class="fa fa-cart-plus"></i> &nbsp;&nbsp;Kitchen Consumables</a>
            </div>
        </div>
        <div class="dropdown">
            <a href="#" class="guestDetails_links inner">Journals</a>
            <div class="dropdown-content">
                <a href="{{url('journal-vouchers')}}">Unauthorized JVs
                    <span style="float: right"><b class="zeroItems">&nbsp;&nbsp;0&nbsp;&nbsp;</b></span>
                </a>
                <hr>
                <a onclick="generalLedgerJv()" style="cursor: pointer">General Ledger JVs </a>
                <a onclick="clientToClientJv()" style="cursor: pointer">Client to Client JVs</a>
                <a onclick="clientToGeneralLedgerJv()" style="cursor: pointer">Clients to GL JVs</a>
            </div>
        </div>
        <div class="dropdown">
            <a href="{{url('#')}}" class="guestDetails_links inner">Bank Account Recon</a>
        </div>
    </div>
</div>

